geojsonloader – BRDR - Aligning borders

# GeoJsonLoader

    loader.GeoJsonLoader(
        id_property=None,
        _input=None,
        source=None,
        source_url=None,
        is_reference=False,
    )

Base class for loaders dealing with GeoJSON-formatted data.

Processes a GeoJSON FeatureCollection into the internal dictionary format.

## Methods

Name | Description
--- | ---
load_data | Parses the GeoJSON input and returns the feature collection.

### load_data

    loader.GeoJsonLoader.load_data()

Parses the GeoJSON input and returns the feature collection.